export function getOriginalLocalStorage(): Storage {
  try {
    if (window.__joliboxLocalStorage__) {
      return window.__joliboxLocalStorage__;
    }

    let originalDescriptor = Object.getOwnPropertyDescriptor(window, 'localStorage');
    if (originalDescriptor && originalDescriptor.get) {
      const originalLocalStorage = originalDescriptor.get.call(window);
      window.__joliboxLocalStorage__ = originalLocalStorage;
      return originalLocalStorage;
    }

    originalDescriptor = Object.getOwnPropertyDescriptor(Object.getPrototypeOf(window), 'localStorage');
    if (originalDescriptor && originalDescriptor.get) {
      const originalLocalStorage = originalDescriptor.get.call(window);
      return originalLocalStorage;
    }

    const windowProto = Window.prototype;
    const protoDescriptor = Object.getOwnPropertyDescriptor(windowProto, 'localStorage');
    if (protoDescriptor && protoDescriptor.get) {
      const protoLocalStorage = protoDescriptor.get.call(window);
      window.__joliboxLocalStorage__ = protoLocalStorage;
      return protoLocalStorage;
    }

    return localStorage;
  } catch (e) {
    console.warn('Failed to get original localStorage, fallback to default implementation', e);
    return localStorage;
  }
}
